pyrcel\.ParcelModel
===================

.. currentmodule:: pyrcel

.. autoclass:: ParcelModel

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ParcelModel.__init__
      ~ParcelModel.run
      ~ParcelModel.save
      ~ParcelModel.set_initial_conditions
      ~ParcelModel.write_csv
      ~ParcelModel.write_summary
   
   

   
   
   